@@ -140,12 +140,16 @@ pub(crate) fn update_rotation(subgizmo: &SubGizmo, ui: &Ui, _ray: Ray) -> Option
         state.current_delta += angle_delta;
     });
 
-    let (scale, mut rotation, translation) = config.model_matrix.to_scale_rotation_translation();
-    rotation = Quat::from_axis_angle(subgizmo.normal(), -angle_delta) * rotation;
+    let rotation =
+        Quat::from_axis_angle(subgizmo.normal(), -angle_delta) * subgizmo.config.rotation;
 
     Some(GizmoResult {
-        transform: Mat4::from_scale_rotation_translation(scale, rotation, translation)
-            .to_cols_array_2d(),
+        transform: Mat4::from_scale_rotation_translation(
+            subgizmo.config.scale,
+            rotation,
+            subgizmo.config.translation,
+        )
+        .to_cols_array_2d(),
         mode: GizmoMode::Rotate,
         value: (subgizmo.normal() * state.current_delta).to_array(),
     })
